==> pagebot-0.6.tar.gz: pagebot-0.6/Lib/pagebot/contributions/filibuster/content/living.py <==
# -*- coding: UTF-8 -*-

"""
        living
- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
"""

__version__ = '4.0'


content = {
        'living_section':    ['Living', 'My life', 'Family', 'Home', 'Kids',
        ],
        'living_headline': ['<#food_headline#>'],
        'food_headline':[
            'Fresh Takes from Island Favorites',
            'Grab a Bite - Breakfast & Lunch',
            u'Eating Out on Martha’s Vineyard',
            'Empower your portal with Real-Time News Feeds and Search',
            'Slow Food',
            '1-year-old farmers marketspreads under 200-year-old oak',
            'Cheese Recall at <#town_us#> Farmers Market',
            u'Farmers Market Vendor Spotlight: Norm’s Apiary',
            'Farmers Market Report: Blueberries Today',
            'Trend: Raspberries and Cabbage Today',
            u'The Green Room: BBMG’s <#name#> Interviews Slow Food Founder',
            'Prawn Singapore Rice Noodles!',
            'The <#town_us#> NAPW Chapter met for dinner',
            'Wine tasting with <#name#>',
            'To market, to <#town_us#> market',
            'Our list of 40 farmers markets across',
            'Stork Craft Custom Tuscany Espresso Finish Glider and Ottoman',
            'Free lower lumbar pillow, Chocolate Cushions',
            '<#time_months#> 2-<#time_monthday#> at <#town_us#> farmers markets',
            'Cheese Recall at <#town_us#> Farmers Market',
            'Farmers market meeting set at <#town_us#>',
            'At <#town_us#> Farmers Market Vendors are Tempting Taste Buds',
        ],
        'living_ankeiler': [
            u"""Scottish Bakehouse on Martha’s Vineyard is a favorite for egg sandwiches, fresh baked pastries, sandwiches, salads, soups and locally sourced main dishes offer islanders and visitors a one-stop option for any meal or snack daily. Offering gluten free options. Catering and take out available. Farmers market on site during the summer!""",
        ],
    }

==> pagebot-0.9.7.tar.gz: pagebot-0.9.7/Lib/pagebot/contributions/filibuster/content/living.py <==
# -*- coding: UTF-8 -*-

"""
living
"""

__version__ = '4.0'


content = {
        'living_section':    ['Living', 'My life', 'Family', 'Home', 'Kids',
        ],
        'living_headline': ['<#food_headline#>'],
        'food_headline':[
            'Fresh Takes from Island Favorites',
            'Grab a Bite - Breakfast & Lunch',
            'Eating Out on Martha’s Vineyard',
            'Empower your portal with Real-Time News Feeds and Search',
            'Slow Food',
            '1-year-old farmers marketspreads under 200-year-old oak',
            'Cheese Recall at <#town_us#> Farmers Market',
            'Farmers Market Vendor Spotlight: Norm’s Apiary',
            'Farmers Market Report: Blueberries Today',
            'Trend: Raspberries and Cabbage Today',
            'The Green Room: BBMG’s <#name#> Interviews Slow Food Founder',
            'Prawn Singapore Rice Noodles!',
            'The <#town_us#> NAPW Chapter met for dinner',
            'Wine tasting with <#name#>',
            'To market, to <#town_us#> market',
            'Our list of 40 farmers markets across',
            'Stork Craft Custom Tuscany Espresso Finish Glider and Ottoman',
            'Free lower lumbar pillow, Chocolate Cushions',
            '<#time_months#> 2-<#time_monthday#> at <#town_us#> farmers markets',
            'Cheese Recall at <#town_us#> Farmers Market',
            'Farmers market meeting set at <#town_us#>',
            'At <#town_us#> Farmers Market Vendors are Tempting Taste Buds',
        ],
        'living_ankeiler': [
            """Scottish Bakehouse on Martha’s Vineyard is a favorite for egg sandwiches, fresh baked pastries, sandwiches, salads, soups and locally sourced main dishes offer islanders and visitors a one-stop option for any meal or snack daily. Offering gluten free options. Catering and take out available. Farmers market on site during the summer!""",
        ],
    }
